@@ -27,9 +27,10 @@ def _needs_qt(function):
         app = None
         if not QApplication.instance():
             app = QApplication([])
-        function(*args, **kwargs)
+        ret = function(*args, **kwargs)
         if app:
             app.exec_()
+        return ret
     return inner
 
 # Make need_qt decorator preserve signature if decorator package is available
@@ -203,5 +204,9 @@ def make_window_legend(win, objects, show_option=None):
 
     legend = []
     for u in objects:
-        legend.append((get_object_color(u), u.name))
+        if u is not None:
+            name = u.name
+        else:
+            name = 'No identifier'
+        legend.append((get_object_color(u), name))
     win.add_color_legend(legend, show_option)
\ No newline at end of file
