@@ -17,8 +17,7 @@ import helper
 
 @helper.needs_qt
 def ISI(trains, bin_size, cut_off, bar_plot=False, unit=pq.ms):
-    """ Create a plot dialog with a interspike interval histogram of units
-    for a list of trials. Read required data from database.
+    """ Create a plot dialog with an interspike interval histogram.
 
     :param dict trains: Dictionary with lists of spike trains indexed by
         units for which to display ISI histograms
@@ -34,7 +33,7 @@ def ISI(trains, bin_size, cut_off, bar_plot=False, unit=pq.ms):
     if not trains:
         raise SpykeException('No spike trains for ISI histogram')
 
-    win_title = 'ISI Histogram | Bin size: %.3f ms' % bin_size
+    win_title = 'ISI Histogram | Bin size: ' + str(bin_size)
     win = PlotDialog(toolbar=True, wintitle=win_title)
     bin_size.rescale(unit)
     cut_off.rescale(unit)
@@ -100,6 +99,8 @@ def ISI(trains, bin_size, cut_off, bar_plot=False, unit=pq.ms):
     else:
         plot.set_antialiasing(True)
 
+    return win
+
 
 if __name__ == '__main__':
     import guidata
