@@ -1,5 +1,5 @@
 """
-.. autofunction:: sde(trains, events=None, start=0 ms, stop=None, kernel_size=100 ms, optimize_steps=0, minimum_kernel=10 ms, maximum_kernel=500 ms, unit=ms, progress=None)
+.. autofunction:: sde(trains, events=None, start=0 ms, stop=None, kernel_size=100 ms, optimize_steps=0, minimum_kernel=10 ms, maximum_kernel=500 ms, kernel_function=None, unit=ms, progress=None)
 """
 import scipy as sp
 
@@ -20,13 +20,13 @@ import helper
 def sde(trains, events=None, start=0*pq.ms, stop=None,
         kernel_size=100*pq.ms, optimize_steps=0,
         minimum_kernel=10*pq.ms, maximum_kernel=500*pq.ms,
-        unit=pq.ms, progress=None):
+        kernel_function=None, unit=pq.ms, progress=None):
     """ Create a spike density estimation plot.
 
     The spike density estimations give an estimate of the instantaneous
     rate. Optionally finds optimal kernel size for given data.
 
-    :param dict trains: A dictionary of SpikeTrain lists.
+    :param dict trains: A dictionary of :class:`neo.core.SpikeTrain` lists.
     :param dict events: A dictionary (with the same indices as ``trains``)
         of Event objects or lists of Event objects. In case of lists,
         the first event in the list will be used for alignment. The events
@@ -52,6 +52,12 @@ def sde(trains, events=None, start=0*pq.ms, stop=None,
     :type minimum_kernel: Quantity scalar
     :param maximum_kernel: The maximum kernel size to try in optimization.
     :type maximum_kernel: Quantity scalar
+    :param kernel_function: The kernel function to use, should accept
+        two parameters: A ndarray of distances and a kernel size.
+        The total area under the kernel function sould be 1. By default,
+        a Gaussian kernel is used. Automatic optimization assumes a
+        Gaussian kernel and will likely not produce optimal results for
+        different kernels.
     :param Quantity unit: Unit of X-Axis.
     :param progress: Set this parameter to report progress.
     :type progress: :class:`spykeutils.progress_indicator.ProgressIndicator`
@@ -59,6 +65,14 @@ def sde(trains, events=None, start=0*pq.ms, stop=None,
     if not progress:
         progress = ProgressIndicator()
 
+        # Catch old API call to remain compatible and make Debian happy.
+        # Can be removed in 0.3.0
+        if isinstance(kernel_function, pq.Quantity):
+            if isinstance(unit, ProgressIndicator):
+                progress = unit
+            unit = kernel_function
+            kernel_function = None
+
     start.units = unit
     if stop:
         stop.units = unit
@@ -66,6 +80,9 @@ def sde(trains, events=None, start=0*pq.ms, stop=None,
     minimum_kernel.units = unit
     maximum_kernel.units = unit
 
+    if kernel_function is None:
+        kernel_function = rate_estimation.gauss_kernel
+
     # Align spike trains
     for u in trains:
         if events:
@@ -79,11 +96,13 @@ def sde(trains, events=None, start=0*pq.ms, stop=None,
             optimize_steps) * unit
         sde, kernel_size, eval_points = \
             rate_estimation.spike_density_estimation(trains, start, stop,
-                optimize_steps=steps, progress=progress)
+                optimize_steps=steps, kernel=kernel_function,
+                progress=progress)
     else:
         sde, kernel_size, eval_points = \
         rate_estimation.spike_density_estimation(trains, start, stop,
-            kernel_size=kernel_size, progress=progress)
+            kernel_size=kernel_size, kernel=kernel_function,
+            progress=progress)
     progress.done()
 
     if not sde:
@@ -118,4 +137,6 @@ def sde(trains, events=None, start=0*pq.ms, stop=None,
     win.add_plot_widget(pW, 0)
     win.add_custom_curve_tools()
     win.add_legend_option([l], True)
-    win.show()
\ No newline at end of file
+    win.show()
+
+    return win
\ No newline at end of file
