@@ -23,10 +23,10 @@ def spike_amplitude_histogram(trains, num_bins, uniform_y_scale=True,
     recording. It shows histograms (one for each `trains` entry, e.g. segment)
     of maximum and minimum spike amplitudes.
 
-    :param list trains: A list of lists of SpikeTrain objects. Each entry of
-        the outer list will be one point on the x-axis (they could correspond
-        to segments), all amplitude occurences of spikes contained in the
-        inner list will be added up.
+    :param list trains: A list of lists of :class:`neo.core.SpikeTrain`
+        objects. Each entry of the outer list will be one point on the
+        x-axis (they could correspond to segments), all amplitude occurences
+        of spikes contained in the inner list will be added up.
     :param int num_bins: Number of bins for the histograms.
     :param bool uniform_y_scale: If True, the histogram for each channel
         will use the same bins. Otherwise, the minimum bin range is computed
@@ -63,4 +63,6 @@ def spike_amplitude_histogram(trains, num_bins, uniform_y_scale=True,
     win.add_x_synchronization_option(True, range(num_channels))
     win.add_y_synchronization_option(uniform_y_scale,
         range(num_channels))
-    win.show()
\ No newline at end of file
+    win.show()
+
+    return win
\ No newline at end of file
