@@ -13,9 +13,10 @@ from . import SpykeException
 
 
 def _binned_spike_trains(trains, bins):
-    """ Return a binned representation of SpikeTrain objects.
+    """ Return a binned representation of spike trains.
 
-    :param sequencs trains: A sequence of SpikeTrain objects.
+    :param sequencs trains: A sequence of :class:`neo.core.SpikeTrain`
+        objects.
     :param bins: The bin edges, including the rightmost edge.
     :type bins: Quantity 1D
     :returns: List of one-dimensional arrays of spike counts.
@@ -30,9 +31,9 @@ def _binned_spike_trains(trains, bins):
 
 def binned_spike_trains(trains, bin_size, start=0*pq.ms, stop=None):
     """ Return dictionary of binned rates for a dictionary of
-    SpikeTrain lists.
+    spike train lists.
 
-    :param dict trains: A sequence of `SpikeTrain` lists.
+    :param dict trains: A dictionary of :class:`neo.core.SpikeTrain` lists.
     :param bin_size: The desired bin size (as a time quantity).
     :type bin_size: Quantity scalar
     :type start: The desired time for the start of the first bin.
@@ -73,9 +74,10 @@ def binned_spike_trains(trains, bin_size, start=0*pq.ms, stop=None):
 
 def psth(trains, bin_size, rate_correction=True, start=0*pq.ms, stop=None):
     """ Return dictionary of peri stimulus time histograms for a dictionary
-    of SpikeTrain lists.
+    of spike train lists.
 
-    :param dict trains: A dictionary of lists of SpikeTrain objects.
+    :param dict trains: A dictionary of lists of :class:`neo.core.SpikeTrain`
+        objects.
     :param bin_size: The desired bin size (as a time quantity).
     :type bin_size: Quantity scalar
     :param bool rate_correction: Determines if a rates (``True``) or
@@ -114,7 +116,7 @@ def aligned_spike_trains(trains, events, copy=True):
     """ Return a list of spike trains aligned to an event (the event will
     be time 0 on the returned trains).
 
-    :param dict trains: A list of SpikeTrain objects.
+    :param dict trains: A list of :class:`neo.core.SpikeTrain` objects.
     :param dict events: A dictionary of Event objects, indexed by segment.
         These events (in case of lists, always the first element in the list)
         will be used to align the spike trains and will be at time 0 for
@@ -152,14 +154,13 @@ def minimum_spike_train_interval(trains):
     """ Computes the minimum starting time and maximum end time that all
     given spike trains share.
 
-    :param dict trains: A dictionary of sequences of SpikeTrain
-        objects.
+    :param dict trains: A dictionary of sequences of
+        :class:`neo.core.SpikeTrain` objects.
     :returns: Maximum shared start time and minimum shared stop time.
     :rtype: Quantity scalar, Quantity scalar
     """
-    # Hoping that nobody needs a 1000 year long spike train
-    start = -1000 * pq.year
-    stop = 1000 * pq.year
+    start = -sp.inf * pq.s
+    stop = sp.inf * pq.s
 
     # Load data and find shortest spike train
     for st in trains.itervalues():
@@ -172,33 +173,45 @@ def minimum_spike_train_interval(trains):
 
 def gauss_kernel(x, kernel_size):
     return 1.0 / (sp.sqrt(2*sp.pi) * kernel_size) * \
-           sp.exp(-x**2 / (2 * kernel_size)**2)
+           sp.exp(-0.5 *  (x / kernel_size)**2)
+
+
+def _hist_density(hist, kernel, ksize, start, stop):
+    time_factor = (2048.0 * start.units / (stop - start)).simplified
+    kern = kernel(sp.arange(-1024,1024), ksize * time_factor)
+    kern *= time_factor / sp.sum(kern)
+    kde = sp.signal.convolve(hist, kern, 'same')
+    return kde
+
+
+def _train_density(train, kernel, ksize):
+    bins = sp.linspace(train.t_start, train.t_stop, 1025)
+    hist = sp.histogram(train, bins)[0]
+    return _hist_density(hist, kernel, ksize, train.t_start, train.t_stop)
 
 
 def spike_density_estimation(trains, start=0*pq.ms, stop=None,
-                             evaluation_points=None, kernel=gauss_kernel,
-                             kernel_size=100*pq.ms, optimize_steps=None,
-                             progress=None):
+                             kernel=gauss_kernel, kernel_size=100*pq.ms,
+                             optimize_steps=None, progress=None):
     """ Create a spike density estimation from a dictionary of
-    lists of SpikeTrain objects. The spike density estimations give
-    an estimate of the instantaneous rate. Optionally finds optimal
-    kernel size for given data.
+    lists of spike trains.
 
-    :param dict trains: A dictionary of SpikeTrain lists.
-    :param start: The desired time for the start of the first bin. It
+    The spike density estimations give an estimate of the instantaneous
+    rate. The density estimation is evaluated at 1024 equally spaced
+    points covering the range of the input spike trains. Optionally finds
+    optimal kernel size for given data using the algorithm from
+    (Shimazaki, Shinomoto. Journal of Computational Neuroscience. 2010).
+
+    :param dict trains: A dictionary of :class:`neo.core.SpikeTrain` lists.
+    :param start: The desired time for the start of the estimation. It
         will be recalculated if there are spike trains which start later
         than this time. This parameter can be negative (which could be
         useful when aligning on events).
     :type start: Quantity scalar
-    :param stop: The desired time for the end of the last bin. It will
+    :param stop: The desired time for the end of the estimation. It will
         be recalculated if there are spike trains which end earlier
         than this time.
     :type stop: Quantity scalar
-    :param evaluation_points: An array of time points at which the
-        density estimation is evaluated to produce the data. If this
-        is None, 1000 equally spaced points covering the range of the
-        input spike trains will be used.
-    :type evaluation_points: Quantity 1D
     :param func kernel: The kernel function to use, should accept
         two parameters: A ndarray of distances and a kernel size.
         The total area under the kernel function sould be 1.
@@ -229,61 +242,58 @@ def spike_density_estimation(trains, start=0*pq.ms, stop=None,
 
     if optimize_steps is None or len(optimize_steps) < 1:
         units = kernel_size.units
+    else:
+        units = optimize_steps.units
+
+    # Prepare evaluation points
+    max_start, max_stop = minimum_spike_train_interval(trains)
+
+    start = max(start, max_start)
+    start.units = units
+    if stop is not None:
+        stop = min(stop, max_stop)
+    else:
+        stop = max_stop
+    stop.units = units
+    bins = sp.linspace(start, stop, 1025)
+    eval_points = bins[:-1] + (bins[1] - bins[0]) / 2
+
+    if optimize_steps is None or len(optimize_steps) < 1:
         kernel_size = {u:kernel_size for u in trains}
     else:
         # Find optimal kernel size for all spike train sets
         progress.set_ticks(len(optimize_steps)*len(trains))
         progress.set_status('Calculating optimal kernel size')
-        units = optimize_steps.units
         kernel_size = {}
         for u,t in trains.iteritems():
             c = collapsed_spike_trains(t)
-            kernel_size[u] = optimal_gauss_kernel_size(c, optimize_steps,
-                progress)
+            kernel_size[u] = optimal_gauss_kernel_size(
+                c.time_slice(start,stop), optimize_steps, progress)
 
-    # Prepare evaluation points
-    if evaluation_points is None:
-        max_start, max_stop = minimum_spike_train_interval(trains)
-
-        start = max(start, max_start)
-        start.units = units
-        if stop is not None:
-            stop = min(stop, max_stop)
-        else:
-            stop = max_stop
-        stop.units = units
-
-        evaluation_points = sp.linspace(start, stop, 1000)
-
-    progress.set_ticks(len(trains) * len(evaluation_points))
+    progress.set_ticks(len(trains))
     progress.set_status('Creating spike density plot')
+
     # Calculate KDEs
     kde = {}
     for u,t in trains.iteritems():
-        this_kde = []
-
         # Collapse spike trains
-        collapsed = sp.asarray(collapsed_spike_trains(t).rescale(units))
+        collapsed = collapsed_spike_trains(t).rescale(units)
         ksize = float(kernel_size[u])
 
-        # Create density estimation
-        for p in evaluation_points:
-            dist = collapsed - float(p)
-
-            this_kde.append(sum(kernel(dist, ksize)))
-            progress.step()
-
-        kde[u] = sp.asarray(this_kde) / len(trains[u]) / units
+        # Create density estimation using convolution
+        kde[u] = _train_density(collapsed.time_slice(start, stop),
+            kernel, ksize) / len(trains[u]) / units
         kde[u].units = pq.Hz
-    return kde, kernel_size, evaluation_points
+    return kde, kernel_size, eval_points
 
 
 def collapsed_spike_trains(trains):
     """ Return a superposition of a list of spike trains.
 
-    :param iterable trains: A list of SpikeTrain objects
-    :returns: A SpikeTrain object containing all spikes of the given
-        SpikeTrain objects.
+    :param iterable trains: A list of :class:`neo.core.SpikeTrain` objects
+    :returns: A spike train object containing all spikes of the given
+        spike trains.
+    :rtype: :class:`neo.core.SpikeTrain`
     """
     if not trains:
         return neo.SpikeTrain([], 0)
@@ -297,16 +307,20 @@ def collapsed_spike_trains(trains):
 
     return neo.SpikeTrain(collapsed*stop.units, t_stop=stop, t_start=start)
 
+
 def optimal_gauss_kernel_size(train, optimize_steps, progress=None):
     """ Return the optimal kernel size for a spike density estimation
-    of a SpikeTrain for a gaussian kernel. This function takes a single
+    of a spike train for a gaussian kernel. This function takes a single
     spike train, which can be a superposition of multiple spike trains
     (created with :func:`collapsed_spike_trains`) that should be included
     in a spike density estimation.
-    See (Shimazaki, Shinomoto. Journal of Computational Neuroscience. 2010).
 
-    :param SpikeTrain train: The spike train for which the kernel
+    Implements the algorithm from
+    (Shimazaki, Shinomoto. Journal of Computational Neuroscience. 2010).
+
+    :param train: The spike train for which the kernel
         size should be optimized.
+    :type train: :class:`neo.core.SpikeTrain`
     :param optimize_steps: Array of kernel sizes to try (the best of
         these sizes will be returned).
     :type optimize_steps: Quantity 1D
@@ -319,19 +333,26 @@ def optimal_gauss_kernel_size(train, optimize_steps, progress=None):
     if not progress:
         progress = ProgressIndicator()
 
-    x = sp.asarray(train.rescale(optimize_steps.units))
+    x = train.rescale(optimize_steps.units)
     steps = sp.asarray(optimize_steps)
 
     N = len(train)
-    tau = sp.triu(sp.vstack([x] * N) - sp.vstack([x] * N).T, 1)
-    idx = sp.triu(sp.ones((N,N)), 1)
-    TAU = tau.T[idx.T==1]**2
-
     C = {}
-    for s in steps:
-        C[s] = N/s + 1/s * sum(2 * sp.exp(-TAU/(4 * s**2)) -
-                               4 * sp.sqrt(2) * sp.exp(-TAU/(2 * s**2)))
+
+    bins = sp.linspace(x.t_start, x.t_stop, 1025)
+    dt = float(bins[1] - bins[0])
+    y_hist = sp.histogram(x, bins)[0] / N / dt
+    for step in steps:
+        s = float(step)
+        yh = _hist_density(y_hist, gauss_kernel, step,
+            train.t_start, train.t_stop)
+
+        # Equation from Matlab code, 7/2012
+        c = (sp.sum(yh**2) * dt -
+             2 * sp.sum(yh * y_hist) * dt +
+             2 * 1 / sp.sqrt(2 * sp.pi) / s / N)
+        C[s] = c * N * N
         progress.step()
 
     # Return kernel size with smallest cost
-    return min(C, key=C.get)*train.units
\ No newline at end of file
+    return min(C, key=C.get)*train.units
